FixedSizeDecodable

Trait FixedSizeDecodable 

pub trait FixedSizeDecodable: Sized {
    type Error;

    const WRONG_SIZE_ERROR: Self::Error;
    const BYTE_SIZE: usize;

    // Required method
    fn decode_checked(buf: &[u8]) -> Result<Self, Self::Error>;
}
A decodable type that has an exact size in bytes.

Required Associated Constants

Required Associated Types

Required Methods

fn decode_checked(buf: &[u8]) -> Result<Self, Self::Error>

Decodes the value. This function assumes that buf is of at least BYTE_SIZE, and assumes that BYTE_SIZE bytes are consumed to decode.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors